#include <avr/io.h>
#include <stdio.h>
#include <util/delay.h>
#include "uart.h"
#include "vinc.h"
#include <avr/eeprom.h>
#include <stdlib.h>
#include <avr/interrupt.h>

#ifndef F_CPU
#define F_CPU 18432000UL
#endif

//ATMega644p

#define LEDlinks 5				//Debug LED
#define LEDrechts 7				//Debug LED
	
#define PARALLELFIFO			//Interface des VNC1L

uint8_t eeFooByte EEMEM;		//Speicherzelle fr Dateinummer
char *filename="welec000.ppm";	//Platzhalter fr Dateiname


// ***********************************************************************
// Liest die aktuelle Dateinummer aus dem EEPROM und aktualisiert das EEPROM
// Parameter:
// Rckgabe: 
// ***********************************************************************
void get_filename()
{
	uint8_t myByte;
	myByte = eeprom_read_byte(&eeFooByte);
	eeprom_write_byte(&eeFooByte, (myByte + 1));
	sprintf(filename,"welec%03d.txt",myByte);		//Dateinamen zusammenbasteln
}

// ***********************************************************************
// ISR fr Datenepfang ber UART
// Parameter:
// Rckgabe: 
// ***********************************************************************
ISR (USART0_RX_vect) {
   //mach was...
}

int main(void)
{
	uint32_t filesize=11;
	

	#ifdef PARALLELFIFO
	PORTC |= (1 << ACBUS5) | ( 1 << nRD);
	DDRC |= (1 << ACBUS5) | (1 << ACBUS6) | (1 << nRD) | (1 << WR);
	#endif

	
	
	DDRD |= (1<<PD6);		// VNC1L zurcksetzen
	_delay_ms(1);
	DDRD &= ~(1<<PD6);
	


	PORTD |= (1 << LEDlinks);
	DDRD |= (1 << LEDlinks) | (1 << LEDrechts)|(1<<PD4);  //PD4 = Pin fr Zeitmessung mit Oszi
	
	
	suart_init();	//SoftUart zum PC: 57.6k 8N1
	uart_init();	//Uart zum Oszi: 115.2k 8N1
	//UCSR0B |= (1<<RXCIE0);	//UART Empfangs Int. aktivieren
	//sei();		//Interrupts global aktivieren

	suart_puts("W2000a USB-Host:\r");		//Begrungs Botschaft
	
	
	_delay_ms(100);	//Warte auf Vinculum
	vinc_prompt();	//Warte auf Prompt im Extended Command Set
	
	
	suart_puts("SCS\r");				//Schalte auf Short Command Set
	vinc_putc(0x10);vinc_putc('\r');
	prompt();							//Warte auf Prompt im SCS
	
	
	while(1)
	{

		get_filename();				//	neuen Dateinamen holen


		vinc_putc(0x09);			// Datei mit Datum neu anlegen
		vinc_putc(' ');
		vinc_puts(filename);
		vinc_putc(' ');
		vinc_put_dword(get_datetime());
		vinc_putc('\r');	
		prompt();

	
		vinc_putc(0x08); vinc_putc(' ');		// schreibe in Datei, 11 Bytes
		vinc_put_dword(filesize);
		vinc_putc('\r');


		// ####################################################################
		// Daten irgendwo besorgen und in Datei schreiben
		vinc_puts("Hallo Welt!");					// == 11 Bytes
		prompt();
		//
		// ####################################################################
	
		
		vinc_putc(0x0A);						//schliee Datei
		vinc_putc(' ');
		vinc_puts(filename);
		vinc_putc('\r');
		prompt();								//Warte auf Prompt

		_delay_ms(1000);
		_delay_ms(1000);
	
	}

	return 0;
}


