#include "uart.h"
#include <avr/io.h>
#include <util/delay.h>

// ***********************************************************************
// Initialisierung der Ports fr dem Soft UART
// Parameter:
// Rckgabe: 
// ***********************************************************************
void suart_init(void){
	PORTD |= (1 << STXD);
	DDRD |= (1 << STXD); 
}

// ***********************************************************************
// Warte auf ein Zeichen der Soft Uart
// Parameter:
// Rckgabe: gelesenes Zeichen
// ***********************************************************************
char suart_getc(void)
{
	uint8_t i;
	char c=0;
	while(PIND & (1 << SRXD));
	_delay_us(17);
		
	for(i=0;i<8;i++)
	{
		if(PIND & (1 << SRXD)) c |= (1<<7);
		
		_delay_us(17);

		c = c >> 1;
	}
	_delay_us(17);
	return c;
}

// ***********************************************************************
// Schreibe einen String auf Soft UART
// Parameter: zu schreibender String
// Rckgabe: 
// ***********************************************************************
void suart_puts (char *s)		//Ausgabe eines Strings
{
    while (*s)
    {   // so lange *s != '\0' also ungleich dem "String-Endezeichen" 
        suart_putc(*s);
        s++;
    }
}

// ***********************************************************************
// Einzelnes Zeichen auf Soft UART schreiben
// Parameter: zu schreibendes Zeichen
// Rckgabe: 
// ***********************************************************************
void suart_putc(char c)
{
	uint8_t i;

	PORTD &= ~(1<<STXD);	//Startbit
	_delay_us(17);	
	
	for(i=0;i<8;i++)
	{
		if(c & 1) PORTD |= (1<<STXD);
		else PORTD &= ~(1 << STXD);
		_delay_us(17);

		c = c >> 1;
	}
	
	PORTD |= (1<<STXD);
	_delay_us(17);
	
//asm volatile ("nop");


}

// ***********************************************************************
// Warte auf ein Zeichen vom UART
// Parameter:
// Rckgabe: gelesenes Zeichen
// ***********************************************************************
uint8_t uart_getc(void)
{
    while (!(UCSR0A & (1<<RXC0)))   // warten bis Zeichen verfuegbar
        ;
    return UDR0;                   // Zeichen aus UDR an Aufrufer zurueckgeben
}

// ***********************************************************************
// UART initialisieren, Baudrate aus uart.h
// Parameter:
// Rckgabe: 
// ***********************************************************************
void uart_init(void){
	UCSR0B |= ( 1 << TXEN0 )|(1 << RXEN0);
	UCSR0C |= ( 1 << UCSZ00 )|( 3<<UCSZ01 );			// Asynchron 8N1
	
													
    UBRR0H  = (UBRR_VAL >>8) & 0xFF;					 
    UBRR0L  = (UBRR_VAL    ) & 0xFF;					 
}

// ***********************************************************************
// Einzelnes Zeichen auf UART schreiben
// Parameter: zu schreibendes Zeichen
// Rckgabe: 
// ***********************************************************************
void uart_putc(char c)		//Ausgabe eines einzelnen Zeichens
{
    while (!(UCSR0A & (1<<UDRE0)));
    UDR0 = c;                      // sende Zeichen 
}


// ***********************************************************************
// Schreibe einen string auf UART
// Parameter: zu schreibender String
// Rckgabe: 
// ***********************************************************************
void uart_puts (char *s)		//Ausgabe eines Strings
{
    while (*s)
    {   // so lange *s != '\0' also ungleich dem "String-Endezeichen" 
        uart_putc(*s);
        s++;
    }
}
