#include <avr/io.h>
#include "vinc.h"
#include "uart.h"

// ***********************************************************************
// Warte bis ein Byte vom VNC1L gelesen werden kann und lies es
// Parameter:
// Rckgabe: gelesenen Wert
// ***********************************************************************
char vinc_getc()
{
	char ret;
	while(PINC & (1<<nRXF));	//Daten knnen nur bei nRXF = 0 gelesen werden
	PORTC &= ~(1 << nRD);		
	asm volatile ("nop"); //54ns warten
	asm volatile ("nop"); //54ns warten
	ret=PINA;
	PORTC |= (1 << nRD);
	return ret;

}

// ***********************************************************************
// Lies ein Byte vom VNC1L, wenn keins da ist, gib NULL zurck
// Parameter:
// Rckgabe: gelesenen Wert oder NULL
// ***********************************************************************
char vinc_getc_nw()
{
	char ret;

	if(PINC & (1<<nRXF)) return 0;
	PORTC &= ~(1 << nRD);		
	asm volatile ("nop"); //54ns warten
	asm volatile ("nop"); //54ns warten
	ret=PINA;
	PORTC |= (1 << nRD);
	return ret;
}

// ***********************************************************************
// Warte bis ein Byte zum VNC1L geschrieben werden kann und schreibe es
// Parameter: zu schreibender Wert
// Rckgabe:
// ***********************************************************************
void vinc_putc(char data)
{
	while(PINC & (1 << nTXE));	//nur bei nTXE=0 schreiben!
	PORTC |= (1 << WR);
	DDRA= 0xFF;
	PORTA = data;
	asm volatile ("nop");
	PORTC &= ~(1 << WR);
	DDRA = 0x00;
}


// ***********************************************************************
// Warte auf den VNC1L und Schreibe einen ASCII String
// Parameter: zu schreibender ASCII String
// Rckgabe:
// ***********************************************************************
void vinc_puts (char *s)		//Ausgabe eines Strings
{
    while (*s)
    {   // so lange *s != '\0' also ungleich dem "String-Endezeichen" 
        vinc_putc(*s);
        s++;
    }
}

// ***********************************************************************
// Warte auf Prompt vom VNC1L im ECS, schreibe Empfangenes auf UART
// Parameter:
// Rckgabe:
// ***********************************************************************
void vinc_prompt()
{
	char dat=0;
	
	do ( dat=vinc_getc(), suart_putc(dat));
	while(dat != '>');
	dat=vinc_getc();	// \r
	suart_putc(dat);

}

// ***********************************************************************
// Auswertung des VNC1L Prompt im Short Command Mode, schreibe auf UART
// Parameter:
// Rckgabe: Fehlercode
// ***********************************************************************
char prompt()
{
	char a,b,ret=11;

	a=vinc_getc();
	b=vinc_getc();

	if(a=='>'){ suart_puts(">\r"); return 0;}	//Allses OK

	else if(a=='B' && b=='C'){ ret=1;}			//Bad Command
	else if(a=='C' && b=='F'){ ret=2;}			//Command Failed
	else if(a=='N' && b=='D'){ ret=3;}			//No Disk
	else if(a=='D' && b=='F'){ ret=4;}			//Disk Full

	else if(a=='F' && b=='I'){ ret=5;}			//Invalid
	else if(a=='R' && b=='O'){ ret=6;}			//Read Only
	else if(a=='F' && b=='O'){ ret=7;}			//File Open
	else if(a=='N' && b=='E'){ ret=8;}			//Dir not empty
	else if(a=='F' && b=='N'){ ret=9;}			//Filename invalid
	else if(a=='N' && b=='U'){ ret=10;}			//No Upgrade

	suart_putc(a);suart_putc(b);suart_putc(vinc_getc());

	
	return ret;
}

// ***********************************************************************
// Liest aktuelle Zeit+Datum aus der RTC und berechnet das Binrformat
// Parameter:
// Rckgabe: Datum+Zeit passend fr VNC1L
// ***********************************************************************
uint32_t get_datetime()
{
	uint8_t year,month,day,hour,minute,second;
	

	year = 2009 - 1980;
	month = 7;
	day = 13;
	hour = 16;
	minute = 0;
	second = 0 / 2;

	/*
	Die Werte von der RTC holen, z.B. DS1337
	*/

	return (uint32_t) ((year * 33554432) | (month * 2097152) | (day * 65536) | (hour * 2048) | (minute *32) | (second * 1) );
}

// ***********************************************************************
// Schickte ein DWORD mit 32Bit zum VNC1L
// Parameter:	zu sendender Wert
// Rckgabe: 
// ***********************************************************************
void vinc_put_dword(uint32_t data)
{
	vinc_putc(data>>24);
	vinc_putc(data>>16);
	vinc_putc(data>>8);
	vinc_putc(data>>0);
}
